# Examples

## lumo.kit

1. [Configurate your params by Params]
2. [Meter everything by Meter and Logger]
3. [Quickly build your dataset by using builder]
5. [Saver: A simple but helpful checkpoints manager]
4. [Manage your train logic by Trainer]
6. [Multi-GPU mode in Trainer]
7. [Global config manager]

## lumo.contrib

1. [collate_fn with callback]
2. [EMA model implement]
3. [Extend for itertools]

## lumo.utils

1. [Save your preprocessing time by cache]
2. [Hash everything]
3. [Save/Load without Exception raised]

## lumo.base_classes

1. [Easier `easy_dict`, attr]
2. [More convenient list, llist]
3. [Tree-like dict]
4. 

## lumo.proc

1. [commen used path, `path`]
2. []

## lumo command line

```shell
```